/**
 *******************************************************************************
 * @file    math_acc_division.c
 *
 * @brief   Implement system specific functions.
 *
 * @author  DP
 *
 * @version V1.0.1
 *
 * @date    2024-11-11
 *
 *******************************************************************************/

/*
    Copyright (c) 2024, DP Microelectronics Inc.

    Redistribution and use in source and binary forms, with or without modification,
are permitted provided that the following conditions are met:

    1. Redistributions of source code must retain the above copyright notice, this
       list of conditions and the following disclaimer.
    2. Redistributions in binary form must reproduce the above copyright notice,
       this list of conditions and the following disclaimer in the documentation
       and/or other materials provided with the distribution.
    3. Neither the name of the copyright holder nor the names of its contributors
       may be used to endorse or promote products derived from this software without
       specific prior written permission.

    THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT,
INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT
NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR
PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY,
WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY
OF SUCH DAMAGE.
*/

/* Files include */
#include "math_acc_division.h"

/**
  * @addtogroup DPM32M036_LibSamples
  * @{
  */

/**
  * @addtogroup MATH_ACC
  * @{
  */

/**
  * @addtogroup MATH_ACC Division
  * @{
  */

/* Private typedef --------------------------------------------------------------*/

/* Private define ---------------------------------------------------------------*/

/* Private macro ----------------------------------------------------------------*/

/* Private variables ------------------------------------------------------------*/
int32_t Divisor = 20;
int32_t Dividendor = 100;
int32_t quotationsvalue,remaindervalue;

/* Private functions ------------------------------------------------------------*/
/**
 *******************************************************************************
 * @brief   MATH_ACC_IRQ_Handler.
 * @param   None.
 * @retval  None.
 ******************************************************************************/
void MATH_ACC_IRQ_Handler(void)
{
  if(MATH_ACC_GetIntFlagStatus()==SET)
  {
    MATH_ACC_ClearIntFlag();
  }
  if(MATH_ACC_GetDivZeroIntFlagStatus()==SET)
  {
    MATH_ACC_ClearDivZeroIntFlag();
  }

}
/**
 *******************************************************************************
 * @brief   MATH_ACC Division Sample.
 * @param   None.
 * @retval  None.
 ******************************************************************************/
void MATH_ACC_Division_Sample(void)
{
  /* Enable clock */
  RCC_Unlock();
  RCC_AHBPeriphClockCmd(RCC_AHB_PERIPH_MATH_ACC, ENABLE);
  RCC_Lock();
 
  /* Enblbe Math acc*/
   MATH_ACC_Cmd(ENABLE);
  /* Enable interrupt */
  MATH_ACC_IntCmd(ENABLE);
  /* Enable Interrupt when the divisor is 0 */
  MATH_ACC_DivZeroIntCmd(ENABLE);
  NVIC_SetPriority(MATH_ACC_IRQn, 2);
  NVIC_EnableIRQ(MATH_ACC_IRQn);

  /* Calculate division */
  MATH_ACC_CalDivision(Divisor,Dividendor,&quotationsvalue,&remaindervalue);
}

/**
  * @}
  */

/**
  * @}
  */

/**
  * @}
  */

/************************ (C) COPYRIGHT DP *****END OF FILE ***************************/
